pub struct UptakeEventExtras {
pub value: Option<String>,
pub source: Option<String>,
pub age: Option<String>,
pub trigger: Option<String>,
pub timestamp: Option<String>,
pub duration: Option<String>,
pub error_name: Option<String>,
}Fields
value: Option<String>Main sync status.
source: Option<String>Source of the sync (eg. “settings-changes-monitoring”, “main/{collection}”, …)
age: Option<String>Age of the data in milliseconds, if available.
trigger: Option<String>Trigger that caused the sync (eg. “manual”, “startup”, “scheduled”, …) if available.
timestamp: Option<String>Timestamp received from the server, if available.
duration: Option<String>Duration of the sync operation in milliseconds, if available.
error_name: Option<String>The name of the error that occurred, if available.